selectiontools.Selection
========================

.. abjad-lineage:: abjad.tools.selectiontools.Selection.Selection.Selection

.. autoclass:: abjad.tools.selectiontools.Selection.Selection.Selection
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.selectiontools.Selection.Selection.Selection.music
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.Selection.Selection.Selection.start_offset
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.Selection.Selection.Selection.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.Selection.Selection.Selection.storage_format
   :noindex:

.. autoattribute:: abjad.tools.selectiontools.Selection.Selection.Selection.timespan
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.selectiontools.Selection.Selection.Selection.__add__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Selection.Selection.Selection.__contains__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Selection.Selection.Selection.__eq__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Selection.Selection.Selection.__ge__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Selection.Selection.Selection.__getitem__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Selection.Selection.Selection.__gt__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Selection.Selection.Selection.__le__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Selection.Selection.Selection.__len__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Selection.Selection.Selection.__lt__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Selection.Selection.Selection.__ne__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Selection.Selection.Selection.__radd__
   :noindex:

.. automethod:: abjad.tools.selectiontools.Selection.Selection.Selection.__repr__
   :noindex:
